==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/EMAILNOTIFICATIONSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EMAILNOTIFICATIONSETUPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMAILNOTIFICATIONSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAILSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMAILNOTIFICATIONSETUPID_Type", propOrder = {
    "emailsequence"
})
public class EMAILNOTIFICATIONSETUPID_Type {

    @XmlElement(name = "EMAILSEQUENCE")
    protected String emailsequence;

    /**
     * Obtient la valeur de la propriété emailsequence.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAILSEQUENCE() {
        return emailsequence;
    }

    /**
     * Définit la valeur de la propriété emailsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAILSEQUENCE(String value) {
        this.emailsequence = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/EMAILNOTIFICATIONSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EMAILNOTIFICATIONSETUPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMAILNOTIFICATIONSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAILSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMAILNOTIFICATIONSETUPID_Type", propOrder = {
    "emailsequence"
})
public class EMAILNOTIFICATIONSETUPID_Type {

    @XmlElement(name = "EMAILSEQUENCE")
    protected String emailsequence;

    /**
     * Gets the value of the emailsequence property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAILSEQUENCE() {
        return emailsequence;
    }

    /**
     * Sets the value of the emailsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAILSEQUENCE(String value) {
        this.emailsequence = value;
    }

}
